pub struct Params<'a> { /* private fields */ }Expand description
Holds both path and query parameters extracted from a URI.
Implementations
Sourceimpl<'a> Params<'a>
impl<'a> Params<'a>
Sourcepub fn iter_path(&mut self) -> &mut Segment<'a, PathSegment> ⓘ
pub fn iter_path(&mut self) -> &mut Segment<'a, PathSegment> ⓘ
Reset and return a mutable iterator over path parameters.
Sourcepub fn iter_query(&mut self) -> &mut Segment<'a, QuerySegment> ⓘ
pub fn iter_query(&mut self) -> &mut Segment<'a, QuerySegment> ⓘ
Reset and return a mutable iterator over query parameters.
Sourcepub fn path_segment(&self) -> &Segment<'_, PathSegment> ⓘ
pub fn path_segment(&self) -> &Segment<'_, PathSegment> ⓘ
Return a reference to the path parameter segment (without resetting iteration).
Sourcepub fn query_segment(&self) -> &Segment<'_, QuerySegment> ⓘ
pub fn query_segment(&self) -> &Segment<'_, QuerySegment> ⓘ
Return a reference to the query parameter segment (without resetting iteration).